pytest-ngsfixtures documentation
==========================================

About
=====

This is a `pytest plugin
<http://doc.pytest.org/en/latest/plugins.html>`_ that enables next
generation sequencing `pytest fixtures
<http://doc.pytest.org/en/latest/fixture.html>`_, including fastq
files and output files from a variety of bioinformatics applications
and tools. There are sequencing fixtures for some common sample
layouts, but it's easy to generate additional sample fixture layouts
using fixture factories.

* Free software: GNU General Public License v3

Features
--------

- a small ngs data set
- predefined sample layouts
- configurable data, reference, and sample fixtures
- wrappers for running shell commands, either in terminals or
  container applications
- wrappers and helper functions for some workflow engines
  

Contents
==========

.. toctree::
   :maxdepth: 2

   installation
   usage
   workflow
   contributing
   authors
   history
   modules



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
